aboutsummaryrefslogtreecommitdiff
path: root/common
diff options
context:
space:
mode:
authorKegsay <kegan@matrix.org>2020-03-30 15:02:20 +0100
committerGitHub <noreply@github.com>2020-03-30 15:02:20 +0100
commit11a8059bba9dbdc855f10e3b380c4a2f245635a2 (patch)
tree61b2ffaa53eecb6d4eef8e275f432734cbb9e606 /common
parentf72b759426c1895b76c16ace526cc788713c2fea (diff)
Rename the typing server to EDU server (#948)
* Blunt move and sed rename * Rename common/ refs to typing * Rename internal stuff in eduserver * Rename docs and scripts * Rename constants/filenames, goimports everything to re-order imports
Diffstat (limited to 'common')
-rw-r--r--common/basecomponent/base.go8
-rw-r--r--common/config/config.go20
-rw-r--r--common/config/config_test.go2
-rw-r--r--common/test/config.go4
4 files changed, 17 insertions, 17 deletions
diff --git a/common/config/config_test.go b/common/config/config_test.go
index 110c8b84..b72f5fad 100644
--- a/common/config/config_test.go
+++ b/common/config/config_test.go
@@ -62,7 +62,7 @@ listen:
sync_api: "localhost:7773"
media_api: "localhost:7774"
appservice_api: "localhost:7777"
- typing_server: "localhost:7778"
+ edu_server: "localhost:7778"
logging:
- type: "file"
level: "info"
diff --git a/common/test/config.go b/common/test/config.go
index 0fed252a..f88e4512 100644
--- a/common/test/config.go
+++ b/common/test/config.go
@@ -106,7 +106,7 @@ func MakeConfig(configDir, kafkaURI, database, host string, startPort int) (*con
cfg.Listen.RoomServer = assignAddress()
cfg.Listen.SyncAPI = assignAddress()
cfg.Listen.PublicRoomsAPI = assignAddress()
- cfg.Listen.TypingServer = assignAddress()
+ cfg.Listen.EDUServer = assignAddress()
// Bind to the same address as the listen address
// All microservices are run on the same host in testing
@@ -117,7 +117,7 @@ func MakeConfig(configDir, kafkaURI, database, host string, startPort int) (*con
cfg.Bind.RoomServer = cfg.Listen.RoomServer
cfg.Bind.SyncAPI = cfg.Listen.SyncAPI
cfg.Bind.PublicRoomsAPI = cfg.Listen.PublicRoomsAPI
- cfg.Bind.TypingServer = cfg.Listen.TypingServer
+ cfg.Bind.EDUServer = cfg.Listen.EDUServer
return &cfg, port, nil
}
diff --git a/common/basecomponent/base.go b/common/basecomponent/base.go
index d1d953f7..8d559f4d 100644
--- a/common/basecomponent/base.go
+++ b/common/basecomponent/base.go
@@ -35,9 +35,9 @@ import (
appserviceAPI "github.com/matrix-org/dendrite/appservice/api"
"github.com/matrix-org/dendrite/common/config"
+ eduServerAPI "github.com/matrix-org/dendrite/eduserver/api"
federationSenderAPI "github.com/matrix-org/dendrite/federationsender/api"
roomserverAPI "github.com/matrix-org/dendrite/roomserver/api"
- typingServerAPI "github.com/matrix-org/dendrite/typingserver/api"
"github.com/sirupsen/logrus"
)
@@ -111,10 +111,10 @@ func (b *BaseDendrite) CreateHTTPRoomserverAPIs() (
return alias, input, query
}
// CreateHTTPTypingServerAPIs returns typingInputAPI for hitting the typing
// server over HTTP
-func (b *BaseDendrite) CreateHTTPTypingServerAPIs() typingServerAPI.TypingServerInputAPI {
- return typingServerAPI.NewTypingServerInputAPIHTTP(b.Cfg.TypingServerURL(), nil)
+func (b *BaseDendrite) CreateHTTPEDUServerAPIs() eduServerAPI.EDUServerInputAPI {
+ return eduServerAPI.NewEDUServerInputAPIHTTP(b.Cfg.EDUServerURL(), nil)
}
// CreateHTTPFederationSenderAPIs returns FederationSenderQueryAPI for hitting
@@ -111,10 +111,10 @@ func (b *BaseDendrite) CreateHTTPRoomserverAPIs() (
return alias, input, query
}
-// CreateHTTPTypingServerAPIs returns typingInputAPI for hitting the typing
+// CreateHTTPEDUServerAPIs returns eduInputAPI for hitting the EDU
// server over HTTP
diff --git a/common/config/config.go b/common/config/config.go
index bd83cbf8..e2f5e663 100644
--- a/common/config/config.go
+++ b/common/config/config.go
@@ -134,7 +134,7 @@ type Dendrite struct {
OutputRoomEvent Topic `yaml:"output_room_event"`
// Topic for sending account data from client API to sync API
OutputClientData Topic `yaml:"output_client_data"`
// Topic for typingserver/api.OutputTypingEvent events.
OutputTypingEvent Topic `yaml:"output_typing_event"`
// Topic for user updates (profile, presence)
UserUpdates Topic `yaml:"user_updates"`
@@ -206,7 +206,7 @@ type Dendrite struct {
RoomServer Address `yaml:"room_server"`
FederationSender Address `yaml:"federation_sender"`
PublicRoomsAPI Address `yaml:"public_rooms_api"`
- TypingServer Address `yaml:"typing_server"`
+ EDUServer Address `yaml:"edu_server"`
} `yaml:"bind"`
// The addresses for talking to other microservices.
@@ -219,7 +219,7 @@ type Dendrite struct {
RoomServer Address `yaml:"room_server"`
FederationSender Address `yaml:"federation_sender"`
PublicRoomsAPI Address `yaml:"public_rooms_api"`
- TypingServer Address `yaml:"typing_server"`
+ EDUServer Address `yaml:"edu_server"`
} `yaml:"listen"`
// The config for tracing the dendrite servers.
@@ -571,7 +571,7 @@ func (config *Dendrite) checkListen(configErrs *configErrors) {
checkNotEmpty(configErrs, "listen.federation_api", string(config.Listen.FederationAPI))
checkNotEmpty(configErrs, "listen.sync_api", string(config.Listen.SyncAPI))
checkNotEmpty(configErrs, "listen.room_server", string(config.Listen.RoomServer))
- checkNotEmpty(configErrs, "listen.typing_server", string(config.Listen.TypingServer))
+ checkNotEmpty(configErrs, "listen.edu_server", string(config.Listen.EDUServer))
}
// checkLogging verifies the parameters logging.* are valid.
@@ -669,7 +669,7 @@ func fingerprintPEM(data []byte) *gomatrixserverlib.TLSFingerprint {
// AppServiceURL returns a HTTP URL for where the appservice component is listening.
func (config *Dendrite) AppServiceURL() string {
- // Hard code the roomserver to talk HTTP for now.
+ // Hard code the appservice server to talk HTTP for now.
// If we support HTTPS we need to think of a practical way to do certificate validation.
// People setting up servers shouldn't need to get a certificate valid for the public
// internet for an internal API.
@@ -685,18 +685,18 @@ func (config *Dendrite) RoomServerURL() string {
return "http://" + string(config.Listen.RoomServer)
}
-// TypingServerURL returns an HTTP URL for where the typing server is listening.
-func (config *Dendrite) TypingServerURL() string {
- // Hard code the typing server to talk HTTP for now.
+// EDUServerURL returns an HTTP URL for where the EDU server is listening.
+func (config *Dendrite) EDUServerURL() string {
+ // Hard code the EDU server to talk HTTP for now.
// If we support HTTPS we need to think of a practical way to do certificate validation.
// People setting up servers shouldn't need to get a certificate valid for the public
// internet for an internal API.
- return "http://" + string(config.Listen.TypingServer)
+ return "http://" + string(config.Listen.EDUServer)
}
// FederationSenderURL returns an HTTP URL for where the federation sender is listening.
func (config *Dendrite) FederationSenderURL() string {
- // Hard code the typing server to talk HTTP for now.
+ // Hard code the federation sender server to talk HTTP for now.
// If we support HTTPS we need to think of a practical way to do certificate validation.
// People setting up servers shouldn't need to get a certificate valid for the public
// internet for an internal API.
@@ -134,7 +134,7 @@ type Dendrite struct {
// Topic for sending account data from client API to sync API
OutputClientData Topic `yaml:"output_client_data"`
- // Topic for typingserver/api.OutputTypingEvent events.
+ // Topic for eduserver/api.OutputTypingEvent events.
OutputTypingEvent Topic `yaml:"output_typing_event"`
// Topic for user updates (profile, presence)